@@ -93,7 +93,7 @@ class EasyRSAv1(EasyRSA):
         return PKCS1_v1_5.new(rsa_key=RSA.import_key(extern_key=self.__private_key)).sign(SHA3_512.new(try_utf8e(msg)))
 
     def verify(self, msg: str_or_bytes, sig: bytes) -> bool:
-        PKCS1_v1_5.new(rsa_key=RSA.importKey(self.__public_key).publickey()).verify(SHA3_512.new(try_utf8e(msg)), sig)
+        PKCS1_v1_5.new(rsa_key=RSA.importKey(self.__public_key).publickey()).verify(msg_hash=SHA3_512.new(try_utf8e(msg)), signature=sig)
         return True
 
 
